local font, fontsize = "Fonts\\FRIZQT__.ttf", 10        -- The font and fontsize 

local backdrop = { 
	bgFile = "Interface\\AddOns\\oUF_DaMT\\media\\HalBackgroundA", tile = true, tileSize = 16, 
    insets = {left = -2, right = -2, top = -2, bottom = -2}, 
} 

local statusbar = [[Interface\Addons\oUF_DaMT\media\HalH]]

local backdrop2 = {
	bgFile = "Interface\\ChatFrame\\ChatFrameBackground",
	insets = {top = -2, left = -1, bottom = -2, right = -2},
}

local layoutName = "oUF_DaMT"

damt = {}

-- frame defaults
damt.db = {
	frames = {
		maintanks = {
			name = "maintanks",
			position = {
				anchorFromPoint = "CENTER",
				anchorTo = 'UIParent',
				anchorToPoint = "CENTER",
				anchorX = 0,
				anchorY = 0,
			},
			attributes = {
				"showRaid",  true,
				"groupFilter" ,"MAINTANK",
				"template", "oUF_DaMT",
				"yOffset", -6
			},
		},
		mainassist = {
			name = "mainassist",
			position = {
				anchorFromPoint = "TOPLEFT",
				anchorTo = "UIParent",
				anchorToPoint = "TOPLEFT",
				anchorX = 15,
				anchorY = -100,
			},
			attributes = {
				"showRaid",  true,
				"groupFilter" ,"MAINASSIST",
				"template", "oUF_DaMT",
				"yOffset", -6
				
			},
		},
	},
}
--== CONFIGS ==--
-- do raid icons
local ricon = true

local framewidth = 120 
local frameheight = 20

function SetFontString(parent, fontName, fontHeight, fontStyle) 
        local fs = parent:CreateFontString(nil, 'OVERLAY') 
        fs:SetFont(fontName, fontHeight, fontStyle) 
        fs:SetJustifyH('LEFT') 
        fs:SetShadowColor(0,0,0) 
        fs:SetShadowOffset(1.25, -1.25) 

    return fs 
end 


-- Provide shortened names
oUF.TagEvents["[shortname]"] = "UNIT_TARGET"
oUF.Tags["[shortname]"] = function(u)
	local name = UnitName(u)
	return (string.len(name) > 10) and string.gsub(name, "%s?(.)%S+%s", "%1. ") or name
end

-- the style
function Style(self, unit)
	
	--== Unit Backgrounds ==--

    self:SetBackdrop(backdrop2)
    self:SetBackdropColor(0,0,0,1)
    
    self:SetAttribute("type1", "target")
    
 
    -- The Health bar 
    self.Health = CreateFrame('StatusBar', "Health", self) 
    self.Health:SetPoint("TOPLEFT") 
    self.Health:SetStatusBarTexture(statusbar) 
    self.Health:SetHeight(frameheight-5) 
    self.Health:SetPoint"RIGHT" 
    self.Health:SetPoint"LEFT" 
    
    
    self.Health.bg = self.Health:CreateTexture(nil, "BORDER")
    self.Health.bg:SetAllPoints(self.Health)
    self.Health.bg:SetTexture(statusbar)
   	self.Health.bg.multiplier = 0.3
	self.Health.colorClass = true
	self.Health.colorClassNPC = true
 	self.Health.colorDisconnected = true;
 	self.Health.frequentUpdates = true;
 
    -- The health Text
    local healthtext = SetFontString(self.Health, font, fontsize) 
    healthtext:SetPoint('RIGHT',self,'RIGHT',-2,0)
    healthtext.frequentUpdates = true
    self:Tag(healthtext,'[perhp]%')
    
    -- The name 
    local name = SetFontString(self.Health, font, fontsize)
 	name:SetPoint('LEFT',self,'LEFT',10,0) 
	name.frequentUpdates = 0.1
    self:Tag(name,'[shortname] [dead]')

     
    --The power (mana, rage,energy or whatever you want) bar 
    self.Power = CreateFrame('StatusBar', "Power" , self) 
    self.Power:SetPoint("TOP", self.Health, "BOTTOM", 0, 0) 
    self.Power:SetHeight(4) 
    self.Power:SetPoint("LEFT")
    self.Power:SetPoint("RIGHT") 
    self.Power.colorPower = true
    self.Power.frequentUpdates = true;

    self.Power.bg = self.Power:CreateTexture(nil, "BORDER")
    self.Power.bg:SetAllPoints(self.Power)
    self.Power.bg:SetTexture(statusbar)
    self.Power.bg.multiplier = 0.3

    
     -- Raid Icons --
    if(ricon)then
        self.RaidIcon = self.Health:CreateTexture(nil, "OVERLAY")
        self.RaidIcon:SetPoint("LEFT", self, 0, 2)
        self.RaidIcon:SetHeight(16)
        self.RaidIcon:SetWidth(16)
        self.RaidIcon.frequentUpdates = 0.1
    end

    self:SetAttribute('initial-height', frameheight)        -- the frames' height 
    self:SetAttribute('initial-width', framewidth)    
    
end 
     
oUF:RegisterStyle('DaMT_Raid', Style) 
oUF:SetActiveStyle('DaMT_Raid') 

local frame, events = CreateFrame("Frame"), {};
function events:ADDON_LOADED(...)
 	if (arg1 == "oUF_DaMT") then
		for index,data in pairs(damt.db.frames)do
			local frame
			frame = oUF:Spawn('header', data.name)
			frame:SetManyAttributes(unpack(data.attributes))
			
			frame:SetPoint(data.position.anchorFromPoint, data.position.anchorX, data.position.anchorY)
			
			frame:Show()
			frame:SetMovable(true)
			frame:SetUserPlaced(enable)
			
			frame.isLocked = true
			
			damt.db.frames[index].frame = frame
			
			
		end
		
	end	
end

frame:SetScript("OnEvent", function(self, event, ...)
 events[event](self, ...); -- call one of the functions above
end);
for k, v in pairs(events) do
 frame:RegisterEvent(k); -- Register all events for which handlers have been defined
end

-- toggle the frame locking
function toggleFrameLock()
	for index,data in pairs(damt.db.frames)do
		data.frame.isLocked = not data.frame.isLocked
	end
end

-- prints stuff
local print = function(msg,type)
	local colour 
	print("|c"..(type~=nil and (type=="error" and "FFFF6600") or (type=="debug" and "FF66FF66") or "FF00FF00") ..layoutName.." : |r"..msg)
end

-- prints the names of the frames used in the layout
function listFrames()
	print("/damt togglelock : Will toggle a frame lock and make them drag-to-move")
	
end

local group
SLASH_OUFDAMT1 = "/damt"
SlashCmdList["OUFDAMT"] = function(cmd)
	if cmd == "" or not cmd then 
		cmd ="help" 
	end
	local tokens = {}
	for token in cmd:gmatch("%S+") do table.insert(tokens, token) end
		
	if(tokens[1] == "help")then
		listFrames()
	elseif(tokens[1] == 'togglelock') then
		toggleFrameLock()
	end
end

